@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0 */
-/* Copyright (C) 2007-2019  B.A.T.M.A.N. contributors:
+/* Copyright (C) B.A.T.M.A.N. contributors:
  *
  * Marek Lindner, Simon Wunderlich
  *
@@ -13,34 +13,19 @@
 #include <linux/version.h>
 #include_next <linux/netdevice.h>
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 17, 0)
-
-/* alloc_netdev() was defined differently before 2.6.38 */
-#undef alloc_netdev
-#define alloc_netdev(sizeof_priv, name, name_assign_type, setup) \
-	alloc_netdev_mqs(sizeof_priv, name, setup, 1, 1)
-
-#endif /* < KERNEL_VERSION(3, 17, 0) */
-
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 1, 0)
-
-#define dev_get_iflink(_net_dev) ((_net_dev)->iflink)
-
-#endif /* < KERNEL_VERSION(3, 19, 0) */
-
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 5, 0)
+#if LINUX_VERSION_IS_LESS(4, 5, 0)
 
 #define netdev_master_upper_dev_link(dev, upper_dev, upper_priv, upper_info, extack) \
 	netdev_master_upper_dev_link(dev, upper_dev)
 
-#elif LINUX_VERSION_CODE < KERNEL_VERSION(4, 15, 0)
+#elif LINUX_VERSION_IS_LESS(4, 15, 0)
 
 #define netdev_master_upper_dev_link(dev, upper_dev, upper_priv, upper_info, extack) \
 	netdev_master_upper_dev_link(dev, upper_dev, upper_priv, upper_info)
 
-#endif /* < KERNEL_VERSION(4, 15, 0) */
+#endif /* LINUX_VERSION_IS_LESS(4, 15, 0) */
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 7, 0)
+#if LINUX_VERSION_IS_LESS(4, 7, 0)
 
 #define netif_trans_update batadv_netif_trans_update
 static inline void batadv_netif_trans_update(struct net_device *dev)
@@ -48,9 +33,9 @@ static inline void batadv_netif_trans_update(struct net_device *dev)
 	dev->trans_start = jiffies;
 }
 
-#endif /* < KERNEL_VERSION(4, 7, 0) */
+#endif /* LINUX_VERSION_IS_LESS(4, 7, 0) */
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 11, 9)
+#if LINUX_VERSION_IS_LESS(4, 11, 9)
 
 /* work around missing attribute needs_free_netdev and priv_destructor in
  * net_device
@@ -67,6 +52,19 @@ static inline void batadv_netif_trans_update(struct net_device *dev)
 #define needs_free_netdev destructor = batadv_softif_free2; t2
 #define priv_destructor destructor = batadv_softif_free2; t1
 
-#endif /* < KERNEL_VERSION(4, 11, 9) */
+#endif /* LINUX_VERSION_IS_LESS(4, 11, 9) */
+
+#if LINUX_VERSION_IS_LESS(5, 10, 0)
+
+#define netif_rx_any_context batadv_netif_rx_any_context
+static inline int batadv_netif_rx_any_context(struct sk_buff *skb)
+{
+	if (in_interrupt())
+		return netif_rx(skb);
+	else
+		return netif_rx_ni(skb);
+}
+
+#endif /* LINUX_VERSION_IS_LESS(5, 10, 0) */
 
 #endif	/* _NET_BATMAN_ADV_COMPAT_LINUX_NETDEVICE_H_ */
